## v0.3.0 (2024-10-08)

### Feat

- [**link**] Improve issue linking in commit messages, closes [#3](https://github.com/kmnhan/cz-changeup/issues/3) ([9758f43](https://github.com/kmnhan/cz-changeup/commit/9758f43ca7e39c46eb77e5333223998f0deb3f9a))

  Now supports linking multiple issues by separating them with spaces. Each issue is now properly linked to its corresponding URL on the base URL provided.

[main 9c88ff6] bump: version 0.2.0 → 0.3.0
 2 files changed, 2 insertions(+), 2 deletions(-)

